diff --git a/migrations/versions/b514cca2d47b_add_user_role.py b/migrations/versions/b514cca2d47b_add_user_role.py
index 69caedbb0bfc8682416592bb5974805f10ab5fbb..058694200fe0e2c1a9b6ca82abf9c023e5562b40 100644
--- a/migrations/versions/b514cca2d47b_add_user_role.py
+++ b/migrations/versions/b514cca2d47b_add_user_role.py
@@ -1,4 +1,4 @@
 """add user role
 
 Revision ID: b514cca2d47b
 Revises: 5f462d2d9d25
@@ -8,8 +8,6 @@ Create Date: 2022-06-08 17:24:51.305129
 from alembic import op
 import sqlalchemy as sa
 
-from areas.apps.apps_service import AppsService
-
 # revision identifiers, used by Alembic.
 revision = 'b514cca2d47b'
 down_revision = '5f462d2d9d25'
@@ -20,6 +18,28 @@ depends_on = None
 def upgrade():
     # ### end Alembic commands ###
 
+    # Check and update app table in DB
+    apps = {
+        "dashboard": "Dashboard",
+        "wekan": "Wekan",
+        "wordpress": "WordPress",
+        "nextcloud": "Nextcloud",
+        "zulip": "Zulip"
+    }
+    # app table
+    app_table = sa.table('app', sa.column('id', sa.Integer), sa.column(
+        'name', sa.String), sa.column('slug', sa.String))
+
+    existing_apps = op.get_bind().execute(app_table.select()).fetchall()
+    existing_app_slugs = [app['slug'] for app in existing_apps]
+    for app_slug in apps.keys():
+        if app_slug in existing_app_slugs:
+            op.execute(f'UPDATE app SET `name` = "{apps.get(app_slug)}" WHERE slug = "{app_slug}"')
+        else:
+            op.execute(f'INSERT INTO app (`name`, slug) VALUES ("{apps.get(app_slug)}","{app_slug}")')
+
+    # Fetch all apps including newly created
+    existing_apps = op.get_bind().execute(app_table.select()).fetchall()
     # Insert role "user" as ID 2
     op.execute("INSERT INTO `role` (id, `name`) VALUES (2, 'user')")
     # Insert role "no access" as ID 3
@@ -27,20 +47,21 @@ def upgrade():
     # Set role_id 2 to all current "user" users which by have NULL role ID
     op.execute("UPDATE app_role SET role_id = 2 WHERE role_id IS NULL")
 
-    # Add 'no access' role for all users that don't have any roles for specific apps 
-    app_ids = [app['id'] for app in AppsService.get_apps()]
-    app_roles = AppsService.get_app_roles()
-    user_ids = [app_role['user_id'] for app_role in app_roles]
+    # Add 'no access' role for all users that don't have any roles for specific apps
+    app_roles_table = sa.table('app_role', sa.column('user_id', sa.String), sa.column(
+        'app_id', sa.Integer), sa.column('role_id', sa.Integer))
+    
+    app_ids = [app['id'] for app in existing_apps]
+    app_roles = op.get_bind().execute(app_roles_table.select()).fetchall()
+    user_ids = set([app_role['user_id'] for app_role in app_roles])
 
     for user_id in user_ids:
-        existing_app_ids = [x['app_id'] for x in list(filter(lambda role: role['user_id'] == user_id, app_roles))]
-        missing_app_ids = [x for x in app_ids if x not in existing_app_ids]
-        
-        if len(missing_app_ids) > 0:
-            insert_statement = "INSERT INTO app_role (user_id, app_id, role_id) VALUES"
-            for app_id in missing_app_ids:
-                insert_statement += " ('"+ user_id +"'," + str(app_id) +",3),"
-            op.execute(insert_statement[:-1])
+        existing_user_app_ids = [x['app_id'] for x in list(filter(lambda role: role['user_id'] == user_id, app_roles))]
+        missing_user_app_ids = [x for x in app_ids if x not in existing_user_app_ids]
+
+        if len(missing_user_app_ids) > 0:
+            values = [{'user_id': user_id, 'app_id': app_id, 'role_id': 3} for app_id in missing_user_app_ids]
+            op.bulk_insert(app_roles_table, values)
 
 
 def downgrade():
@@ -1,4 +1,4 @@
-"""add user role
+"""update apps and add 'user' and 'no access' role
 
 Revision ID: b514cca2d47b